@@ -30,17 +30,17 @@ class knownValues(unittest.TestCase):
     def testL4Object_asa_range01(self):
         pp = L4Object(protocol='tcp', port_spec='range smtp 32', syntax='asa')
         self.assertEqual(pp.protocol, 'tcp')
-        self.assertEqual(pp.port_list, [25, 26, 27, 28, 29, 30, 31, 32])
+        self.assertEqual(pp.port_list, range(25, 33))
 
     def testL4Object_asa_lt01(self):
         pp = L4Object(protocol='tcp', port_spec='lt echo', syntax='asa')
         self.assertEqual(pp.protocol, 'tcp')
-        self.assertEqual(pp.port_list, [1, 2, 3, 4, 5, 6])
+        self.assertEqual(pp.port_list, range(1, 7))
 
     def testL4Object_asa_lt02(self):
         pp = L4Object(protocol='tcp', port_spec='lt 7', syntax='asa')
         self.assertEqual(pp.protocol, 'tcp')
-        self.assertEqual(pp.port_list, [1, 2, 3, 4, 5, 6])
+        self.assertEqual(pp.port_list, range(1, 7))
 
 
 if __name__ == "__main__":
